@@ -1,4 +1,4 @@
-#' Model predicted residual outliers 
+#' Model predicted residual outliers  
 #' 
 #' Compute model predicted residuals for each variable using regression
 #' estimated factor scores. 
@@ -9,11 +9,15 @@
 #' @param model if a single numeric number declares number of factors to extract in 
 #' exploratory factor analysis. If \code{class(model)} is a sem (or OpenMx model if installed 
 #' from github) then a confirmatory approach is performed instead
-#' @param na.rm logical; remove cases with missing data?
+#' @param na.rm logical; remove rows with missing data? Note that this is required for 
+#' EFA analysis and \code{sem} fitted models
 #' @param digits number of digits to round in the final result
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
 #' @seealso
 #' \code{\link{gCD}}, \code{\link{LD}}, \code{\link{robustMD}}
+#' @references
+#' Flora, D. B., LaBrish, C. & Chalmers, R. P. (2012). Old and new ideas for data screening and assumption testing for 
+#' exploratory and confirmatory factor analysis. \emph{Frontiers in Psychology, 3}, 1-21. 
 #' @keywords covariance
 #' @export obs.resid
 #' @examples 
@@ -158,7 +162,7 @@ print.obs.resid <- function(x, restype = 'obs', ...)
 #' @param type type of plot to use, default displays points and lines
 plot.obs.resid <- function(x, y = NULL, main = 'Observed Residuals', 
 	type = c('p','h'), restype = 'obs', ...)
-{
+{    
 	ylab <- switch(restype,
 		obs = 'Observed residuals',
 		res = 'Observed variable residuals',
@@ -169,16 +173,16 @@ plot.obs.resid <- function(x, y = NULL, main = 'Observed Residuals',
 		stat[i] <- x$std_res[i, ] %*% x$std_res[i, ]	
 	if(restype == 'obs'){
 		dat <- data.frame(stat=stat,ID=ID)
-		ret <- xyplot(stat~ID, dat, type = type, main = main, ylab = ylab, ...)
+		ret <- lattice::xyplot(stat~ID, dat, type = type, main = main, ylab = ylab, ...)
 	}
 	if(restype == 'res' || restype == 'std_res'){
 		if(restype == 'res') dat <- data.frame(ID=ID,x$res)
 			else dat <- data.frame(ID=ID,x$std_res)
 		rownames(dat) <- ID
-		dat2 <- reshape(dat, v.names='res', direction = 'long', varying=2:ncol(dat), timevar='variable', sep='')	
-		ret <- xyplot(res~ID|as.factor(variable), dat2, type = type, main = main, ylab = ylab, ...)		
+		dat2 <- reshape(dat, v.names='res', direction = 'long', varying=2:ncol(dat), 
+                        times = colnames(dat)[-1], timevar='variable', sep='')	
+		ret <- lattice::xyplot(res~ID|as.factor(variable), dat2, type = type, main = main, 
+                               ylab = ylab, ...)		
 	}
 	return(ret)
 }
-
-
